/***************************************************************************
 * Copyright 2012 Kieker Project (http://kieker-monitoring.net)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.beans.request;

import java.util.ArrayList;
import java.util.List;

import kieker.webgui.common.Role;

/**
 * This simple bean is request scoped and can be used to store the necessary data for a new user during a request. It is not to be used to deliver a list of users
 * for example, as there is a field for a password.
 * 
 * @author Nils Christian Ehmke
 */
public class NewUserBean {

	private List<Role> roles;
	private String username;
	private String password;

	/**
	 * Creates a new instance of this bean and initializes it with empty fields. <b>Do not use this constructor. This bean is Spring managed.</b>
	 */
	public NewUserBean() {
		this.roles = new ArrayList<Role>();
		this.username = "";
		this.password = "";
	}

	/**
	 * Delivers the current value of the property {@link NewUserBean#roles}.
	 * 
	 * @return The current value of the property.
	 */
	public List<Role> getRoles() {
		return this.roles;
	}

	/**
	 * Setter for the property {@link NewUserBean#roles}.
	 * 
	 * @param roles
	 *            The new value for the property.
	 */
	public void setRoles(final List<Role> roles) {
		this.roles = roles;
	}

	/**
	 * Delivers the current value of the property {@link NewUserBean#username}.
	 * 
	 * @return The current value of the property.
	 */
	public String getUsername() {
		return this.username;
	}

	/**
	 * Setter for the property {@link NewUserBean#username}.
	 * 
	 * @param username
	 *            The new value for the property.
	 */
	public void setUsername(final String username) {
		this.username = username;
	}

	/**
	 * Delivers the current value of the property {@link NewUserBean#password}.
	 * 
	 * @return The current value of the property.
	 */
	public String getPassword() {
		return this.password;
	}

	/**
	 * Setter for the property {@link NewUserBean#password}.
	 * 
	 * @param password
	 *            The new value for the property.
	 */
	public void setPassword(final String password) {
		this.password = password;
	}

}
